# Best Practices and Tutorials
### On this page
  * [Building Initial Data Repository](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials#building-initial-data-repository)
  * [Mapping and Synchronization](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials#mapping-and-synchronization)
  * [Insights from Reports](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials#insights-from-reports)
  * [Process Governance in SAP Signavio](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials#process-governance-in-sap-signavio)
  * [Business Transformation Planning in SAP LeanIX](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials#business-transformation-planning-in-sap-leanix)
  * [Managing Application Lifecycles in SAP Signavio](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials#managing-application-lifecycles-in-sap-signavio)
  * [Synchronizing Lifecycle Phases](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials#synchronizing-lifecycle-phases)
  * [Ensuring Only Active Applications in Processes](https://help.sap.com/docs/leanix/ea/best-practices-and-tutorials#ensuring-only-active-applications-in-processes)


View all
Explore best practices for SAP Signavio integration, covering initial data setup, mapping and synchronization, insights from reports, process governance, and application lifecycle management.
